==> haskell-crypton-conduit-0.2.3-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-7xUMUoVYKIrIgRiqTeU2M5
key:                  crypton-conduit-0.2.3-7xUMUoVYKIrIgRiqTeU2M5
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  d559f5c54db8f43406d32f46e92c68c5
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-7xUMUoVYKIrIgRiqTeU2M5
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-I25roZFZ9rtE9pq7CzsSgq
    conduit-extra-1.3.6-7TbX0I2WNNG4Wr86Zc6tp0
    crypton-0.34-5oxuOJnBr8m3Lk3YkjhBKV exceptions-0.10.5
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    resourcet-1.2.6-Emy1WDuYe6W3crmrzZuLqP transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-conduit-0.2.3-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-93GR2Q7euK9IX5CPD5S86r
key:                  crypton-conduit-0.2.3-93GR2Q7euK9IX5CPD5S86r
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  d6798f17d2bf8ffad09d6b8290a6d2b1
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-93GR2Q7euK9IX5CPD5S86r
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-LOkHLh1PoPRERxCd5mJQIE
    conduit-extra-1.3.6-BzKgmnVk1FZLGurLLJ1Lls
    crypton-0.34-FBCi8YNA1Yo8PBEQxV02X0 exceptions-0.10.5
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    resourcet-1.2.6-223TkNfardcC3p5LC28WLD transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
